diff --git a/python/dune/perftool/compile.py b/python/dune/perftool/compile.py
index fdcee2cc1b42db201a9f17a31fd4d19e770fff53..18e620d02382b32e9896436f101297defc88a26d 100644
--- a/python/dune/perftool/compile.py
+++ b/python/dune/perftool/compile.py
@@ -87,10 +87,19 @@ def read_ufl(uflfile):
     # Extract and preprocess the forms
     data = interpret_ufl_namespace(namespace)
 
     # Enrich data by some additional objects we deem worth keeping
     if get_option("exact_solution_expression"):
         data.object_by_name[get_option("exact_solution_expression")] = namespace[get_option("exact_solution_expression")]
 
+    magic_names = ("dirichlet_expression",
+                   "is_dirichlet",
+                   "initial_condition",
+                   "exact_solution",
+                   )
+    for name in magic_names:
+        data.object_by_name[name] = namespace.get(name, None)
+
     formdatas = []
     forms = data.forms
     for index, form in enumerate(forms):
@@ -87,10 +87,19 @@ def read_ufl(uflfile):
     data = interpret_ufl_namespace(namespace)
 
-    # Enrich data by some additional objects we deem worth keeping
+    # Enrich data by some additional objects to whose name we attached some
+    # special meaning.
     if get_option("exact_solution_expression"):
         data.object_by_name[get_option("exact_solution_expression")] = namespace[get_option("exact_solution_expression")]